@@ -5,10 +5,12 @@ NULL
 #'
 #' This reporter will simply throw an error if any of the tests failed. It is
 #' best combined with another reporter, such as the
-#' \code{\link{SummaryReporter}}.
+#' [SummaryReporter].
 #'
 #' @export
-FailReporter <- R6::R6Class("FailReporter", inherit = Reporter,
+#' @family reporters
+FailReporter <- R6::R6Class("FailReporter",
+  inherit = Reporter,
   public = list(
     failed = FALSE,
 
